Module spec

Module spec 

Available on crate feature catalog only.
Serde config types for the top-level catalog: block (#279).

Structs

CatalogSpec
The top-level catalog: block: opts a faucet run / schedule / replicate pipeline into recording the Data Movement Catalog after every successful root invocation. faucet serve records into its --history backend automatically — this block is for the non-serve runtimes (and for faucet catalog, which reads the same store).