pub fn sink_guarantee(kind: &str) -> SinkGuaranteeExpand description
The strongest delivery guarantee a sink kind can uphold
(Sink::sink_guarantee, issue #292). Derived from
IDEMPOTENT_SINK_KINDS / UPSERT_SINK_KINDS.
pub fn sink_guarantee(kind: &str) -> SinkGuaranteeThe strongest delivery guarantee a sink kind can uphold
(Sink::sink_guarantee, issue #292). Derived from
IDEMPOTENT_SINK_KINDS / UPSERT_SINK_KINDS.