Module spec

Module spec 

Available on crate feature schedule only.
Config types for the schedule: block.

Structs

ScheduleSpec
Top-level schedule: block. Presence of this block is what makes a config runnable by faucet schedule.

Enums

OverlapPolicy
Behaviour when a tick fires while a run is still in progress.
ScheduleOnFailure
Per-run failure policy.