build_probe

Function build_probe 

pub fn build_probe(queue: &QueueSpec) -> Result<Box<dyn DepthProbe>, String>
Available on crate feature serve and crate feature triggers and (crate features triggers-kafka or triggers-redis) only.
Build the depth probe for a queue spec (feature-gated backends).