pub fn declared(doc: &Value) -> CliResult<ParamsSpec>Expand description
Read the params: block out of an untyped config document, validating it.
A document with no block yields an empty spec.
pub fn declared(doc: &Value) -> CliResult<ParamsSpec>Read the params: block out of an untyped config document, validating it.
A document with no block yields an empty spec.