Available on crate feature
schedule only.Expand description
Config types for the schedule: block.
Structs
- Schedule
Spec - Top-level
schedule:block. Presence of this block is what makes a config runnable byfaucet schedule.
Enums
- Overlap
Policy - Behaviour when a tick fires while a run is still in progress.
- Schedule
OnFailure - Per-run failure policy.